@@ -11,14 +11,6 @@ if (!defined('SM_PATH')) {
 }
 
 include_once(SM_PATH . 'include/validate.php');
-/*
-* include already done by src/option.php
-*
-* include_once(SM_PATH . 'include/forms.php');
-* include_once(SM_PATH . 'include/display_messages.php');
-*/
-/** UTF7 support */
-include_once(SM_PATH . 'functions/imap_utf7_local.php');
 
 function expire_get_config()
 {
@@ -45,7 +37,7 @@ function expire_defaults() {
     textdomain('expire');
 
     if (!is_dir($expire_dir . ".")) {
-        if(!@mkdir($expire_dir, 0777)) {
+        if(!@mkdir($expire_dir, 07777)) {
     	    error_box(_("Cannot create option directory!") . " " .
        	    	      _("Please contact system administrator."), $color);
     	    return;
@@ -196,7 +188,7 @@ function  expire_write($box, $exp, $msg) {
 	    if ($msg == true) {
     		sqsession_register($color[9], 'exp_msg_col');
     		sqsession_register(sprintf(_("Expiration modified successfully for folder %s."),  
-    		                   htmlspecialchars(imap_utf7_decode_local($box))), 'exp_msg');
+    		                   htmlspecialchars($box)), 'exp_msg');
 	    }
 	}
     }  
@@ -209,7 +201,7 @@ function  expire_write($box, $exp, $msg) {
 	    if ($msg == true) {
 		sqsession_register($color[9], 'exp_msg_col');
     		sqsession_register(sprintf(_("Expiration deleted successfully for folder %s."),  
-    		                   htmlspecialchars(imap_utf7_decode_local($box))), 'exp_msg');
+    	    	        	   htmlspecialchars($box)), 'exp_msg');
 	    }
 	}
     } else {
@@ -218,7 +210,7 @@ function  expire_write($box, $exp, $msg) {
         if ($msg == true) {
 	    sqsession_register($color[9], 'exp_msg_col');
     	    sqsession_register(sprintf(_("Expiration set successfully for folder %s."),  
-  	                       htmlspecialchars(imap_utf7_decode_local($box))), 'exp_msg');
+        	    	       htmlspecialchars($box)), 'exp_msg');
 	}
     }
     
