@@ -33,7 +33,7 @@ function expire_check($parms) {
 }
 
 function expire_version() {
-    return '1.3.1';
+    return '1.3';
 }
 
 ?>
